@@ -8,6 +8,7 @@ import json
 import os
 from distutils.sysconfig import get_python_lib
 from os import path
+import site
 
 from AWSIoTPythonSDK.MQTTLib import AWSIoTMQTTShadowClient
 
@@ -123,7 +124,7 @@ class Robot:
             useWebsocket=True)
         self.shadow_client.configureEndpoint(self._cloud.mqtt_endpoint, 443)
         setuppath='/usr/local/etc/aws-root-ca1.cer'
-        pippath=get_python_lib()
+        pippath=site.USER_SITE if path.exists("%s/usr/local/etc/aws-root-ca1.cer" % site.USER_SITE) else get_python_lib()
         cerpath=setuppath if path.exists(setuppath) else "%s/usr/local/etc/aws-root-ca1.cer" % pippath
         self.shadow_client.configureCredentials(cerpath)
         self.shadow_client.configureIAMCredentials(
@@ -254,9 +255,9 @@ class Robot:
             for room_id in room_ids.split(','):
                 logger.info('  - %s (%s)', self.get_room_name(room_id),
                             room_id)
-            regions = [{'region_id': room_id}
+            regions = [{'type':'rid', 'region_id': room_id}
                        for room_id in room_ids.split(',')] \
-                if ',' in room_ids else [{'region_id': room_ids}]
+                if ',' in room_ids else [{'region_id': room_ids, 'type': 'rid'}]
             payload.update({
                 'pmap_id': self._current_map_id,
                 'regions': regions,
